@@ -79,41 +79,45 @@ grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
 echo "TO/FROM" >> $TESTTMP/result
 from="2001:db8::/32"
 to="2001:db8:3:4:5:6:7:8"
-for x in allow deny
+for x in allow deny limit
 do
+        context="2"
+        if [ "$x" = "limit" ]; then
+                context="5"
+        fi
         do_cmd "0"  $x from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
 
         do_cmd "0"  $x from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to port 25
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to port 25
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to port 25 from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to port 25 from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to port 25 from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to port 25 from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
         for y in udp tcp
         do
                 do_cmd "0"  $x from $from port 80 proto $y
@@ -291,4 +295,31 @@ grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
 do_cmd "0" delete allow from ::1/32 to ::1/128
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
 
+echo "TESTING MULTIPORT" >> $TESTTMP/result
+do_cmd "0" allow to 2001:0db8:85a3:08d3:1319:8a2e:0370:7341 port 80:83 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" delete allow to 2001:0db8:85a3:08d3:1319:8a2e:0370:7341 port 80:83 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" allow to 2001:0db8:85a3:08d3:1319:8a2e:0370:7341 port 80:83,22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" delete allow to 2001:0db8:85a3:08d3:1319:8a2e:0370:7341 port 80:83,22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" allow from 2001:0db8:85a3:08d3:1319:8a2e:0370:7341 port 35:39 to 2001:0db8:85a3:08d3:1319:8a2e:0370:7342 port 22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" delete allow from 2001:0db8:85a3:08d3:1319:8a2e:0370:7341 port 35:39 to 2001:0db8:85a3:08d3:1319:8a2e:0370:7342 port 22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" allow to any port 23,21,15:19,22 from any port 24:26 proto udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" delete allow to any port 23,21,15:19,22 from any port 24:26 proto udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" allow 23,21,15:19,22/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+do_cmd "0" delete allow 23,21,15:19,22/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user6.rules >> $TESTTMP/result
+
+
 exit 0
