@@ -14,7 +14,8 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-sed -i 's/disable_checks = False/disable_checks = True/' $TESTPATH/usr/sbin/ufw
+sed -i 's/do_checks = True/do_checks = False/' $TESTPATH/lib/python/ufw/backend.py
+cp tests/defaults/profiles/* $TESTPATH/etc/ufw/applications.d
 
 let count=0
 do_cmd() {
@@ -30,7 +31,7 @@ do_cmd() {
 	fi
 
         echo "$count: $@" >> $TESTTMP/result
-        $TESTPATH/usr/sbin/ufw $@ >> $cmd_results_file 2>&1
+        $TESTPATH/usr/sbin/ufw "$@" >> $cmd_results_file 2>&1
 	rc="$?"
 	if [ "$rc" != "$expected" ]; then
 		echo "Command '$@' exited with '$rc', but expected '$expected'"
@@ -39,5 +40,9 @@ do_cmd() {
         let count=count+1
         echo "" >> $TESTTMP/result
         echo "" >> $TESTTMP/result
+
+        individual=$(cat $statsdir/individual)
+        let individual=individual+1
+        echo $individual > $statsdir/individual
 }
 
